@@ -25,17 +25,14 @@ protected:
 
 	void replaceViewer(InfiniteScrollViewer* viewer);
 
-	void setLandscape();
-	void setPortrait();
-
-	bool event(QEvent* ev);
-
 	virtual void keyPressEvent(QKeyEvent* event);
 	void selectVerse(QString startingFilter);
 	void search(QString text, QString scope);
 	void startSearch(QString text);
 
 	InfiniteScrollViewer* createViewer(QString book, int chapter, int verse);
+	InfiniteScrollViewer* createViewerWithHighlight(QString book, int chapter,
+												int verse, QString highlight);
 
 protected slots:
 	void onSelectVerse();
@@ -43,7 +40,6 @@ protected slots:
 	void onSearch();
 	void onSettings();
 	void goToVerse(QString verse);
-	void orientationChanged(const QString& newOrientation);
 
 private:
 	BibleInfo* mBible;
